@@ -98,7 +98,7 @@ static const char *errElmSize = "Invalid ElmSize (%d)";
 static const char *errCheckRect = "Invalid selection!";
 static const char *errDimIndexValue = "Invalid Dimension Len (%d)!";
 static const char *errLoadModeError = "Only allow to change load mode in a read-only file.";
-static const char *errPackedMode = "Invalid packed mode '%s'.";
+static const char *errPackedMode = "Invalid compression method '%s'.";
 
 #define pnCnt		0
 #define pnDATA		1
@@ -1528,6 +1528,15 @@ void CdVectorX::DeleteDim()
 	}
 }
 
+void CdVectorX::ClearDim()
+{
+	if (!fDims.empty())
+	{
+		Clear();
+		fDims.clear();
+	}
+}
+
 void CdVectorX::GetDimLen(Int32 *Dims) const
 {
 	vector<TdDimItem>::const_iterator it;
